#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.Indicators;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Strategies in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Strategies.GomPro
{
	public class GomMPPrevPOCSampleStrat : Strategy
	{
		private Indicators.GomPro.GomMPProLevels gmpl;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Fades previous POC (long only)";
				Name										= "GomMPPreviousPOCSampleStrat";
				Calculate									= Calculate.OnBarClose;
				EntriesPerDirection							= 1;
				EntryHandling								= EntryHandling.AllEntries;
				IsExitOnSessionCloseStrategy				= true;
				ExitOnSessionCloseSeconds					= 30;
				IsFillLimitOnTouch							= false;
				MaximumBarsLookBack							= MaximumBarsLookBack.TwoHundredFiftySix;
				OrderFillResolution							= OrderFillResolution.Standard;
				Slippage									= 0;
				StartBehavior								= StartBehavior.WaitUntilFlat;
				TimeInForce									= TimeInForce.Gtc;
				TraceOrders									= false;
				RealtimeErrorHandling						= RealtimeErrorHandling.StopCancelClose;
				StopTargetHandling							= StopTargetHandling.PerEntryExecution;
				BarsRequiredToTrade							= 20;
				// Disable this property for performance gains in Strategy Analyzer optimizations
				// See the Help Guide for additional information
				IsInstantiatedOnEachOptimizationIteration	= true;
				Target					= 10;
				Stop					= 10;

			}
			else if (State == State.Configure)
			{
				SetProfitTarget("L", CalculationMode.Ticks, Target);
				SetStopLoss("L", CalculationMode.Ticks, Stop, false);
				// Adding the 1 min data series we need since we will be using MinuteData source
				AddDataSeries(BarsPeriodType.Minute, 1);	
			}
			else if (State == State.DataLoaded)
			{	
				// you can use the ninja strategy builder to get the correct initializer
				// here are the enums:
				
				//public enum DataSourceType{ File, MinuteData};
				//public enum Periodicity	{Bar,EveryNBar,Daily,Weekly,Monthly}
				//public enum ProfileData {Volume,Tick}
				
				gmpl	= GomMPProLevels(Gom.MP.DataSourceType.MinuteData,1,Gom.MP.Periodicity.Daily,
										  1,0,Gom.MP.ProfileData.Volume,false,"09:00:00","17:30:00",
											Gom.Lib.GomTZ.TIMEZONE_LOCAL,false,70,5);
			}
		}

		protected override  void OnBarUpdate()
		{
			// check if BarsInProgress==0 (main data series)
			if (BarsInProgress==0 && IsFirstTickOfBar)
			{
				gmpl.Update();
				
				if (Close[0]> gmpl.PreviousPOC[0])
					EnterLongLimit(Convert.ToInt32(DefaultQuantity), gmpl.PreviousPOC[0], "L");		
			}
		}


		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Target", Order=1, GroupName="Parameters")]
		public int Target
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Stop", Order=2, GroupName="Parameters")]
		public int Stop
		{ get; set; }
		
		#endregion

	}
}
